@@ -1,11 +1,12 @@
 from .NetworkError import NetworkError
 from .RPCClient import RPCClient
+from .RPCServer import RPCServer
 from .DobotlinkAdapter import DobotlinkAdapter
 from .Utils import loggers
 from .Magician import MagicianApi
 from .MagicBox import MagicBoxApi
 from .Lite import LiteApi
+from .M1 import M1Api
 
-
-__all__ = ("loggers", "RPCClient", "DobotlinkAdapter", "NetworkError",
-           "MagicianApi", "LiteApi", "MagicBoxApi")
+__all__ = ("loggers", "RPCClient", "RPCServer", "DobotlinkAdapter",
+           "NetworkError", "MagicianApi", "LiteApi", "MagicBoxApi", "M1Api")
